%define module	sympy
%define check_tests 0

Summary:	Python library for symbolic mathematics
Name:		python-%{module}
Version:	1.0
Release:	%mkrel 1
Source0:	https://github.com/%{module}/%{module}/releases/download/%{module}-%{version}/%{module}-%{version}.tar.gz
License:	BSD
Group:		Development/Python
Url:		http://sympy.googlecode.com/
Requires: 	python-numpy
Requires:	python-mpmath
Requires:	python-matplotlib
Recommends:	python-gmpy >= 1.03
Recommends:     python-pyglet
BuildRequires:	python-devel
BuildRequires:	python-sphinx
BuildRequires:	python-mpmath
# For docs
BuildRequires:  librsvg 
BuildRequires:  imagemagick
BuildArch:	noarch
# for tests
BuildRequires:  x11-font-type1
BuildRequires:  x11-server-xvfb

%description
SymPy is a Python library for symbolic mathematics. It aims to become
a full-featured computer algebra system (CAS) while keeping the code
as simple as possible in order to be comprehensible and easily
extensible. SymPy is written entirely in Python and does not require
any external libraries, except optionally for plotting support.

%package texmacs
Summary:        TeXmacs integration for sympy
Group:		Development/Python
Requires:       %{name} = %{version}-%{release}, TeXmacs

%description texmacs
This package contains a TeXmacs plugin for sympy.

%package examples
Summary:        Sympy examples
Group:		Development/Python
Requires:       %{name} = %{version}-%{release}

%description examples
This package contains example input for sympy.

%package doc
Summary:        Documentation for sympy
Group:		Development/Python

%description doc
man  and HTML documentation for sympy.

%package -n python3-%{module}
Summary:        Python 3 library for symbolic mathematics
Group:		Development/Python
BuildRequires:	python3-devel
BuildRequires:	python3-mpmath
Requires: 	python3-numpy
Requires:	python3-mpmath
Requires:	python3-matplotlib

%description -n python3-%{module}
SymPy is a Python 3 library for symbolic mathematics. It aims to become
a full-featured computer algebra system (CAS) while keeping the code
as simple as possible in order to be comprehensible and easily
extensible. SymPy is written entirely in Python 3 and does not require
any external libraries, except optionally for plotting support.

%prep
%setup -q -n sympy-%{version}

%build
%py2_build

pushd doc
make html
popd

%py3_build

%install
%py3_install
cp -a %{buildroot}%{_bindir}/isympy %{buildroot}%{_bindir}/python3-isympy
%py2_install
# Remove extra files
rm -f %{buildroot}%{_bindir}/{,doc}test

# Install the TeXmacs integration
cp -p data/TeXmacs/bin/tm_sympy %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_datadir}/TeXmacs/plugins/sympy
cp -a data/TeXmacs/progs %{buildroot}%{_datadir}/TeXmacs/plugins/sympy

# Don't let an executable script go into the documentation
chmod a-x examples/all.py

# Install the HTML documentation
mkdir -p %{buildroot}%{_docdir}/%{name}-doc
cp -a doc/_build/html %{buildroot}%{_docdir}/%{name}-doc
rm -f %{buildroot}%{_docdir}/%{name}-doc/html/.buildinfo
rm -fr %{buildroot}%{_docdir}/%{name}-doc/i18n

%if 0%check_tests
%check
# The python3 tests fail with Unicode errors without this
export LC_ALL=en_US.UTF-8
let "dnum = $RANDOM % 90 + 10"
xvfb-run -n $dnum python2 setup.py test
xvfb-run -n $dnum python3 setup.py test
%endif

%files
%doc AUTHORS LICENSE PKG-INFO 
%{python2_sitelib}/sympy/
%{python2_sitelib}/sympy-%{version}-*.egg-info
%{_bindir}/isympy

%files texmacs
%doc data/TeXmacs/LICENSE
%{_bindir}/tm_sympy
%{_datadir}/TeXmacs/plugins/sympy/

%files examples
%doc examples

%files doc
%docdir %{_docdir}/%{name}-doc/html
%{_docdir}/%{name}-doc/html
%{_mandir}/man1/isympy.1*

%files -n python3-%{module}
%doc AUTHORS LICENSE PKG-INFO 
%{python3_sitelib}/sympy/
%{python3_sitelib}/sympy-%{version}-*.egg-info
%{_bindir}/python3-isympy



%changelog
* Tue Apr 19 2016 joequant <joequant> 1.0-1.mga6
+ Revision: 1003550
- fix build typo
- update to 1.0

* Sat Feb 20 2016 umeabot <umeabot> 0.7.6.1-3.mga6
+ Revision: 971174
- Mageia 6 Mass Rebuild

* Sun Oct 11 2015 joequant <joequant> 0.7.6.1-2.mga6
+ Revision: 889446
- simplify and upgrade to 3.5
- revert python-sympy removal

* Thu Sep 24 2015 philippem <philippem> 0.7.6.1-1.mga6
+ Revision: 883378
- update to 0.7.6.1

* Wed Jan 28 2015 joequant <joequant> 0.7.6-1.mga5
+ Revision: 812581
- add imagemagick
- fix comments
- add librsvg to sympy
- update sympy to 0.7.6

* Wed Oct 15 2014 umeabot <umeabot> 0.7.3-8.mga5
+ Revision: 746274
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.7.3-7.mga5
+ Revision: 729867
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 0.7.3-6.mga5
+ Revision: 688373
- Mageia 5 Mass Rebuild

  + tv <tv>
    - s/uggests:/Recommends:/

* Sat May 31 2014 pterjan <pterjan> 0.7.3-5.mga5
+ Revision: 629051
- Rebuild for new Python

* Fri Nov 22 2013 philippem <philippem> 0.7.3-4.mga4
+ Revision: 552336
- add missing requires python-mpmath and python-matplotlib fix mga#11736

* Tue Oct 22 2013 umeabot <umeabot> 0.7.3-3.mga4
+ Revision: 544340
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 0.7.3-2.mga4
+ Revision: 499514
- Rebuild to add different pythonegg provides for python 2 and 3

* Thu Oct 03 2013 philippem <philippem> 0.7.3-1.mga4
+ Revision: 490623
-update to 0.7.3
- add Python 3
- split doc , examples and texmacs in subpackages

* Sun Jan 13 2013 umeabot <umeabot> 0.7.1-2.mga3
+ Revision: 379552
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Sep 20 2011 lebedov <lebedov> 0.7.1-1.mga2
+ Revision: 146159
- imported package python-sympy

